"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_tools_1 = require("graphql-tools");
const TypeStructure_1 = require("./structures/TypeStructure");
const SchemaStructure_1 = require("./structures/SchemaStructure");
exports.makeSchema = (rootType, { types }) => {
    const typeDefinitions = [rootType, ...types].map(type => new TypeStructure_1.TypeStructure(type));
    const { literals, mutations, resolvers } = new SchemaStructure_1.SchemaStructure(typeDefinitions);
    const hasMutations = Object.keys(mutations).length !== 0;
    const schema = `
    schema {
      query: ${rootType.name}
      ${hasMutations ? 'mutation: Mutation' : ''}
    }
    ${hasMutations ? 'type Mutation' : ''}
  `;
    const schemaDefinition = {
        typeDefs: [schema, ...literals],
        resolvers: Object.assign({ Mutation: mutations }, resolvers),
    };
    if (!hasMutations) {
        delete schemaDefinition.resolvers.Mutation;
    }
    return graphql_tools_1.makeExecutableSchema(schemaDefinition);
};
//# sourceMappingURL=schema.js.map